============================================
``psyclone.psyir.nodes.structure_reference``
============================================

.. automodule:: psyclone.psyir.nodes.structure_reference

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.structure_reference


Classes
=======

- :py:class:`StructureReference`:
  Node representing a reference to a component of a structure. As such


.. autoclass:: StructureReference
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: StructureReference
      :parts: 1
